To access the anonymised data optained from a medical professional for the results section of the irp report, please click on the [following link](https://imperiallondon-my.sharepoint.com/:x:/g/personal/bg721_ic_ac_uk/EfYf7LuW5K5BhME_ydKXYtYBFj8BxSOrRvYUI7h1hy6hUA?e=lnYFRu)
